/***************************************************************************
* DTD to XML Schema translator (dtd2xsd)
* Version 1.0
****************************************************************************
* Copyright (C) 2001 Ralf Schweiger
* 
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
* 
* Contact the Author:
*
* University of Giessen
* c/o Ralf Schweiger
* Heinrich-Buff-Ring 44
* 35392 Giessen
* Germany
*
* tel.:   +49-641-9941370
* fax.:   +49-641-9941359
* mailto: Ralf.Schweiger@informatik.med.uni-giessen.de
*
***************************************************************************/
/**
 * dtd => rec-xmlschema-1-20010502
 */

import java.io.*;
import dtd2xs;

public class dtd2xsd {

   private static dtd2xs translator = new dtd2xs(System.err);

   private static void usage() {
      System.err.println(
         "usage: java dtd2xsd <2options> <dtd file>" +
         "\n<2options>" +
         "\n   -resolveEntities               resolve DTD entities" +
         "\n   -preserveComments <5options>   preserve DTD comments" +
         "\n<5options>" +
         "\n   - means default" +
         "\n   <commentLanguage> null         en de fr ..." +
         "\n   <maxLengthComment> 1000" +
         "\n   <conceptRelation> true" +
         "\n   <schemaConcepts> \"element enumeration\"" +
         "\n   <minRelation> 20               heuristics for comment-concept-relation"
      );
      System.exit(1);
   }

   public static void main(String [] argument) {
      try {
         int i = 0; // index of current argument
         if (argument.length < 1) usage();
         boolean resolveEntities = argument[i].startsWith("-resolveEntities");
         if (resolveEntities)
            if (argument.length < 2) usage(); else ++ i;
         boolean preserveComments = argument[i].startsWith("-preserveComments");
         String commentLanguage = null;
         int maxLengthComment = 1000;
         boolean conceptRelation = true;
         String schemaConcepts = "element enumeration";
         int minRelation = 20;
         if (preserveComments)
            if (i + 6 < argument.length) {
               if (! argument[i + 1].equals("-")) commentLanguage = argument[i + 1];
               if (! argument[i + 2].equals("-")) maxLengthComment = Integer.valueOf(argument[i + 2]).intValue();
               conceptRelation = argument[i + 3].equals("-") || argument[i + 3].equals("true");
               if (! argument[i + 4].equals("-")) schemaConcepts = argument[i + 4];
               if (! argument[i + 5].equals("-")) minRelation = Integer.valueOf(argument[i + 5]).intValue();
               i += 6;
            }
            else usage();
         File dtd = new File(argument[i]);
         String xsd = translator.translate("file:///" + dtd.getAbsolutePath(), resolveEntities, preserveComments, commentLanguage, maxLengthComment, conceptRelation, schemaConcepts, minRelation);
         System.out.println(xsd);
         System.exit(0);
      }
      catch (Exception x) { System.err.println(x); System.exit(1); }
   }

}

